@@ -67,13 +67,13 @@ mod tests {
     #[test]
     fn test_command_borrowed_from_command() {
         let command = Command {
-            application_id: Some(ApplicationId(1)),
+            application_id: Some(ApplicationId::new(1).expect("non zero")),
             default_permission: Some(true),
             description: "command description".to_owned(),
-            guild_id: Some(GuildId(2)),
+            guild_id: Some(GuildId::new(2).expect("non zero")),
             kind: CommandType::ChatInput,
             name: "command name".to_owned(),
-            id: Some(CommandId(3)),
+            id: Some(CommandId::new(3).expect("non zero")),
             options: Vec::from([CommandOption::Boolean(BaseCommandOptionData {
                 description: "command description".to_owned(),
                 name: "command name".to_owned(),
