@@ -45,8 +45,8 @@ impl<'a> SetGuildCommands<'a> {
 
     fn request(&self) -> Result<Request, Error> {
         Request::builder(&Route::SetGuildCommands {
-            application_id: self.application_id.0,
-            guild_id: self.guild_id.0,
+            application_id: self.application_id.get(),
+            guild_id: self.guild_id.get(),
         })
         .json(&self.commands)
         .map(RequestBuilder::build)
