@@ -28,8 +28,10 @@ mod private {
             integration::DeleteGuildIntegration,
             member::{AddRoleToMember, RemoveMember, RemoveRoleFromMember, UpdateGuildMember},
             role::{CreateRole, DeleteRole, UpdateRole},
+            sticker::{CreateGuildSticker, UpdateGuildSticker},
             CreateGuildChannel, CreateGuildPrune, UpdateGuild,
         },
+        user::UpdateCurrentUser,
     };
 
     /// Sealed stops crates other crates implementing the trait.
@@ -63,9 +65,12 @@ mod private {
     impl<'a> Sealed for CreateRole<'a> {}
     impl<'a> Sealed for DeleteRole<'a> {}
     impl<'a> Sealed for UpdateRole<'a> {}
+    impl<'a> Sealed for CreateGuildSticker<'a> {}
+    impl<'a> Sealed for UpdateGuildSticker<'a> {}
     impl<'a> Sealed for UpdateGuild<'a> {}
     impl<'a> Sealed for UpdateThread<'a> {}
     impl Sealed for UpdateWebhookMessage<'_> {}
+    impl<'a> Sealed for UpdateCurrentUser<'a> {}
 }
 
 impl AuditLogReasonError {
@@ -155,8 +160,10 @@ mod test {
             integration::DeleteGuildIntegration,
             member::{AddRoleToMember, RemoveMember, RemoveRoleFromMember, UpdateGuildMember},
             role::{CreateRole, DeleteRole, UpdateRole},
+            sticker::{CreateGuildSticker, UpdateGuildSticker},
             CreateGuildChannel, CreateGuildPrune, UpdateGuild,
         },
+        user::UpdateCurrentUser,
     };
     use static_assertions::{assert_impl_all, assert_obj_safe};
 
@@ -190,5 +197,8 @@ mod test {
     assert_impl_all!(CreateRole<'_>: AuditLogReason<'static>);
     assert_impl_all!(DeleteRole<'_>: AuditLogReason<'static>);
     assert_impl_all!(UpdateRole<'_>: AuditLogReason<'static>);
+    assert_impl_all!(CreateGuildSticker<'_>: AuditLogReason<'static>);
+    assert_impl_all!(UpdateGuildSticker<'_>: AuditLogReason<'static>);
     assert_impl_all!(UpdateGuild<'_>: AuditLogReason<'static>);
+    assert_impl_all!(UpdateCurrentUser<'_>: AuditLogReason<'static>);
 }
