@@ -25,7 +25,7 @@ struct CreateWebhookFields<'a> {
 /// # #[tokio::main]
 /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
 /// let client = Client::new("my token".to_owned());
-/// let channel_id = ChannelId(123);
+/// let channel_id = ChannelId::new(123).expect("non zero");
 ///
 /// let webhook = client
 ///     .create_webhook(channel_id, "Twily Bot")
@@ -69,7 +69,7 @@ impl<'a> CreateWebhook<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Webhook> {
         let mut request = Request::builder(&Route::CreateWebhook {
-            channel_id: self.channel_id.0,
+            channel_id: self.channel_id.get(),
         });
 
         request = match request.json(&self.fields) {
