@@ -20,7 +20,7 @@ use twilight_model::{guild::Ban, id::GuildId};
 /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
 /// let client = Client::new("my token".to_owned());
 ///
-/// let guild_id = GuildId(1);
+/// let guild_id = GuildId::new(1).expect("non zero");
 ///
 /// let bans = client.bans(guild_id).exec().await?;
 /// # Ok(()) }
@@ -41,7 +41,7 @@ impl<'a> GetBans<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Ban>> {
         let request = Request::from_route(&Route::GetBans {
-            guild_id: self.guild_id.0,
+            guild_id: self.guild_id.get(),
         });
 
         self.http.request(request)
