@@ -27,7 +27,7 @@ impl<'a> GetGuildInvites<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Invite>> {
         let request = Request::from_route(&Route::GetGuildInvites {
-            guild_id: self.guild_id.0,
+            guild_id: self.guild_id.get(),
         });
 
         self.http.request(request)
