@@ -71,7 +71,7 @@ impl<'a> UpdateGuildWelcomeScreen<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<WelcomeScreen> {
         let mut request = Request::builder(&Route::UpdateGuildWelcomeScreen {
-            guild_id: self.guild_id.0,
+            guild_id: self.guild_id.get(),
         });
 
         request = match request.json(&self.fields) {
