@@ -64,8 +64,8 @@ impl<'a> UpdateUserVoiceState<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
         let mut request = Request::builder(&Route::UpdateUserVoiceState {
-            guild_id: self.guild_id.0,
-            user_id: self.user_id.0,
+            guild_id: self.guild_id.get(),
+            user_id: self.user_id.get(),
         });
 
         request = match request.json(&self.fields) {
